import React, { Component, ChangeEvent } from 'react';


// Represents one item in the todo list.
type TodoItem = {name: string; completed: boolean;};

type TodoProps = {initialItems: TodoItem[]};
type TodoState = {items: TodoItem[]};

export class Todo extends Component<TodoProps, TodoState> {
  constructor(props: TodoProps) {
    super(props);

    this.state = {items: props.initialItems.slice(0)};
  }

  render = (): JSX.Element => {
    return (
      <div>
        <h2>To-Do List</h2>
        {this.renderItems()}
      </div>);
  };

  renderItems = (): JSX.Element[] => {
    const items: JSX.Element[] = [];
    for (let i = 0; i < this.state.items.length; i++) {
      const item = this.state.items[i];
      const id = "check_" + item.name;
      if (item.completed) {
        items.push(<div className="form-check" key={item.name}>
            <input className="form-check-input" type="checkbox"
                id={id} checked={true} readOnly={true} />
            <label className="form-check-label completed" htmlFor={id}>
              {item.name}
            </label>
          </div>);

      } else {
        items.push(<div className="form-check" key={item.name}>
            <input className="form-check-input" type="checkbox"
                id={id} checked={false}
                onChange={(e) => this.doItemChange(e, i)}/>
            <label className="form-check-label" htmlFor={id}>
              {item.name}
            </label>
          </div>);
      }
    }
    return items;
  };

  doItemChange = (_evt: ChangeEvent<HTMLInputElement>, index: number): void => {
    // Make a list without the item at this index.
    const newItems = this.state.items.slice(0, index).concat(this.state.items.slice(index + 1));

    // Update the state to display these items only.
    this.setState({items: newItems});
  };
}